==> ccx_1.5.src.tar.bz2: CalculiX/ccx_1.5/src/spooles.h <==
/*     CALCULIX - A 3-dimensional finite element program                 */
/*              Copyright (C) 1998 Guido Dhondt                          */
/*     This program is free software; you can redistribute it and/or     */
/*     modify it under the terms of the GNU General Public License as    */
/*     published by the Free Software Foundation; either version 2 of    */
/*     the License, or (at your option) any later version.               */

/*     This program is distributed in the hope that it will be useful,   */
/*     but WITHOUT ANY WARRANTY; without even the implied warranty of    */ 
/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the      */
/*     GNU General Public License for more details.                      */

/*     You should have received a copy of the GNU General Public License */
/*     along with this program; if not, write to the Free Software       */
/*     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.         */

#ifndef __CCX_SPOOLES_H
#define __CCX_SPOOLES_H

/*
 * seperated from CalculiX.h: otherwise everyone would have to include
 * the spooles header files
 */
#include <misc.h>
#include <FrontMtx.h>
#include <SymbFac.h>
#if USE_MT
#include <MT/spoolesMT.h>
#endif

/* increase this for debugging */
#define DEBUG_LVL	0

struct factorinfo 
{
	int size;
	double cpus[11];
	IV *newToOldIV, *oldToNewIV;
	SolveMap *solvemap;
	FrontMtx *frontmtx;
	SubMtxManager *mtxmanager;
	ETree *frontETree;
	int nthread;
	FILE *msgFile;

};

void spooles_factor(double *ad, double *au, double *adb, double *aub, 
                    double *sigma, int *icol, int *irow,
                    int *neq, int *nzs);

void spooles_solve(double *b, int *neq);

void spooles_cleanup();

#endif

==> ccx_2.0.src.tar.bz2: CalculiX/ccx_2.0/src/spooles.h <==
/*     CALCULIX - A 3-dimensional finite element program                 */
/*              Copyright (C) 1998 Guido Dhondt                          */
/*     This program is free software; you can redistribute it and/or     */
/*     modify it under the terms of the GNU General Public License as    */
/*     published by the Free Software Foundation; either version 2 of    */
/*     the License, or (at your option) any later version.               */

/*     This program is distributed in the hope that it will be useful,   */
/*     but WITHOUT ANY WARRANTY; without even the implied warranty of    */ 
/*     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the      */
/*     GNU General Public License for more details.                      */

/*     You should have received a copy of the GNU General Public License */
/*     along with this program; if not, write to the Free Software       */
/*     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.         */

#ifndef __CCX_SPOOLES_H
#define __CCX_SPOOLES_H

/*
 * seperated from CalculiX.h: otherwise everyone would have to include
 * the spooles header files
 */
#include <misc.h>
#include <FrontMtx.h>
#include <SymbFac.h>
#if USE_MT
#include <MT/spoolesMT.h>
#endif

/* increase this for debugging */
#define DEBUG_LVL	0

struct factorinfo 
{
	int size;
	double cpus[11];
	IV *newToOldIV, *oldToNewIV;
	SolveMap *solvemap;
	FrontMtx *frontmtx;
	SubMtxManager *mtxmanager;
	ETree *frontETree;
	int nthread;
	FILE *msgFile;

};

void spooles_factor(double *ad, double *au, double *adb, double *aub, 
                    double *sigma, int *icol, int *irow,
                    int *neq, int *nzs, int *symmetryflag,
                    int *inputformat);

void spooles_solve(double *b, int *neq);

void spooles_cleanup();

#endif
